variacni.rada <- function(X, row.names){
  X  <- as.numeric(X)
  U  <- sort(unique(X))
  nu <- length(U)
  nj <- rep(0, nu)
  for(j in 1 : nu){
    nj[j] <- sum(X == U[j])
  }
  
  n  <- sum(nj)
  pj <- nj/n
  Nj <- cumsum(nj)
  Fj <- cumsum(pj)
  
  variacni.rada <- data.frame(nj = nj, pj = pj, Nj = Nj, Fj = Fj)
  row.names(variacni.rada) <- row.names
  variacni.rada
}

dotplot <- function(x, y, sd = 0.05, xlab = 'x', ylab = 'y', xlim = c(min(x), max(x)), las = 1, ylim = c(min(y), max(y)), 
                    col = 'black', pch = 21, bg = 'white', cex = 1, lwd = 1, axes = T, asp = T)
{
  rand.x <- rnorm(length(x), 0, sd)
  rand.y <- rnorm(length(y), 0, sd)
  x <- x + rand.x
  y <- y + rand.y
  plot(x, y, las = las, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, col = col, 
       pch = pch, bg = bg, lwd = lwd, cex = cex, axes = axes, asp = asp)
}

odds.ratio.test <- function(x, conf.level = 0.95){
  a <- x[1, 1]
  b <- x[1, 2]
  c <- x[2, 1]
  d <- x[2, 2]
  alpha <- 1 - conf.level
  OR <- (a / b) / (c / d)
  lnOR <- log(OR)
  s <- sqrt(1 / a + 1 / b + 1 / c + 1 / d)
  t0 <- lnOR / s
  dh <- lnOR - s * qnorm(1 - alpha / 2)
  hh <- lnOR + s * qnorm(1 - alpha / 2)
  df.exp <- exp(dh)
  hh.exp <- exp(hh)
  p <- 2 * min(pnorm(t0), 1 - pnorm(t0))
  tab <- data.frame(OR, lnOR, t0, dh, hh, p)
  return(tab)
}

trc <- function(X, breaks){
  X <- na.omit(X)
  h <- hist(X, breaks = breaks, plot = F)
  n <- length(X)
  dj <- rep(unique(diff(breaks)), length(breaks) - 1)
  xj <- h$mids 
  nj <- h$counts
  pj <- h$counts / n
  Nj <- cumsum(nj)
  Fj <- cumsum(pj)
  fj <- pj / dj
  tab <- data.frame(dj, xj, nj, pj, Nj, Fj, fj)
  return(tab)
}

d2norm <- function(x, y, n = 100, lim = c(0, 1, 0, 1)){
  x <- na.omit(x)
  y <- na.omit(y)
  mx <- mean(x)
  my <- mean(y)
  sx <- sd(x)
  sy <- sd(y)
  r12 <- cor(x, y, method = 'pearson')
  Mu <- c(mx, my)
  Sig <- matrix(c(sx ^ 2, r12 * sx * sy, r12 * sx * sy, sy ^ 2), 
                ncol = 2, nrow = 2)
  x <- seq(from = lim[1], to = lim[2], length = n)
  y <- seq(from = lim[3], to = lim[4], length = n)
  z <- matrix(NA, n, n)
  for(i in 1:length(x)){
    for(j in 1:length(y)){
      z[i, j] <- mvtnorm::dmvnorm(c(x[i], y[j]), mean = Mu, sigma = Sig)
    }
  }
  return(list(x = x, y = y, z = z))
}

